@@ -25,6 +25,7 @@
 #include "classes/chessclockwidget.h"
 #include "classes/startwidget.h"
 #include "classes/timecontrol.h"
+#include "classes/turninformation.h"
 
 // Time controls
 #include "classes/timecontrol/notimecontrol.h"
@@ -71,6 +72,10 @@ ChessClockWindow::ChessClockWindow(QWidget *parent)
     menuBar()->addAction( tr("About"),this, SLOT(about()));
     menuBar()->addAction(tr("About Qt"), this, SLOT(aboutQt()));
 
+    //set the event filter to grap window deactivate
+
+    installEventFilter(this);
+
 }
 
 void ChessClockWindow::pause()
@@ -140,6 +145,7 @@ void ChessClockWindow::startGame(TimeControl *timecontrol)
         clocks_ = newWidget;
         stack_->addWidget(clocks_);
         stack_->setCurrentWidget(clocks_);
+        connect( clocks_, SIGNAL(TurnFinished(TurnInformation*)), this, SLOT(dontEatMemory(TurnInformation*)));
     }
 }
 
@@ -148,3 +154,19 @@ ChessClockWindow::~ChessClockWindow()
 {
 
 }
+
+bool ChessClockWindow::eventFilter(QObject *obj, QEvent *event)
+{
+    if (event->type() == QEvent::WindowDeactivate) {
+        pause();
+        return QObject::eventFilter(obj,event);
+    } else {
+        // standard event processing
+        return QObject::eventFilter(obj, event);
+    }
+}
+
+void ChessClockWindow::dontEatMemory(TurnInformation *turnInformation)
+{
+    delete turnInformation; // hopefully don't cause Segematation Fault
+}
