@@ -28,6 +28,7 @@ class ClocksWidget;
 class StartWidget;
 class TimeControl;
 class QStackedWidget;
+class TurnInformation;
 
 class ChessClockWindow : public QMainWindow
 {
@@ -45,10 +46,17 @@ public slots:
     void visitWeb();
     void about();
     void aboutQt();
+    /*! Delete turn information to avoid memory leaks
+
+      @todo Save turn log and function to show it.
+    @since 1.1.2 */
+    void dontEatMemory(TurnInformation* turnInformation);
 
 
 protected:
     void initTimeControls();
+    /*! Pauses the game if the application main window is not active e.g. the app is minimized*/
+    bool eventFilter(QObject *obj, QEvent *event);
 
 protected:
     ClocksWidget*   clocks_;
