@@ -109,6 +109,9 @@ ClocksWidget::ClocksWidget(ChessClock *white, ChessClock *black, QWidget *parent
 
     // ScreenLitKeeper to keep screen lit when playing
     keeper_ = new ScreenLitKeeper(this);
+
+    connect( white, SIGNAL(dontEatBattery()), this, SLOT(saveScreen()));
+    connect( black, SIGNAL(dontEatBattery()), this, SLOT(saveScreen()));
 }
 
 ClocksWidget::~ClocksWidget()
@@ -147,6 +150,11 @@ void ClocksWidget::stopPlay()
     status_ = Stopped;
 }
 
+void ClocksWidget::saveScreen()
+{
+    keeper_->keepScreenLit(false);
+}
+
 
 void ClocksWidget::mouseReleaseEvent(QMouseEvent *event)
 {
@@ -192,7 +200,7 @@ void ClocksWidget::mouseReleaseEvent(QMouseEvent *event)
             break;
         case BlackPause:
             // Continue play
-            keeper_->keepScreenLit(false);
+            keeper_->keepScreenLit(true);
             pauseLabel_->setVisible(false);
             pauseButton_->setVisible(true);
             black_->continueTurn();
